#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <string>

#include <QMainWindow>
#include <QSet>
#include <QSettings>
#include <QString>
#include <QStandardPaths>

QT_BEGIN_NAMESPACE
namespace Ui { class MainWindow; }
QT_END_NAMESPACE

class MainWindow : public QMainWindow
{
		Q_OBJECT

	public:
		MainWindow(QWidget *parent = nullptr);
		~MainWindow();

	protected:
		void showEvent(QShowEvent *event);
		void keyPressEvent(QKeyEvent *event);

	private slots:
		void createClick();
		void fileStateChanged();
		void findFileClick();
		void radioSubsectionCheckedChanged();

	private:
		std::string createSubsectionHeading();


		Ui::MainWindow *ui;
		QSet<QString> subjects;
		QSettings settings;

#ifndef NDEBUG	// debugging mode

		const QString includesTexPath = "includes.tex";
		const QString definitionsTexPath = "definitions.tex";
		const QString sectionTexPath = "section.tex";
		const QString documentHeaderTexPath = "document_header.tex";
		const QString documentBodyPureTexPath = "document_body_pure.tex";
		const QString documentBodyThemeTexPath = "document_body_theme.tex";

#else			// no debugging mode
		const QString includesTexPath =
				QStandardPaths::locate(QStandardPaths::AppLocalDataLocation, "includes.tex");
		const QString definitionsTexPath =
				QStandardPaths::locate(QStandardPaths::AppLocalDataLocation, "definitions.tex");
		const QString sectionTexPath =
				QStandardPaths::locate(QStandardPaths::AppLocalDataLocation, "section.tex");
		const QString documentHeaderTexPath =
				QStandardPaths::locate(QStandardPaths::AppLocalDataLocation, "document_header.tex");
		const QString documentBodyPureTexPath =
				QStandardPaths::locate(QStandardPaths::AppLocalDataLocation, "document_body_pure.tex");
		const QString documentBodyThemeTexPath =
				QStandardPaths::locate(QStandardPaths::AppLocalDataLocation, "document_body_theme.tex");
#endif

		QString includesTexContent;
		QString definitionsTexContent;
		QString sectionTexContent;
		QString documentHeaderTexContent;
		QString documentBodyPureTexContent;
		QString documentBodyThemeTexContent;
};
#endif // MAINWINDOW_H
